@@ -3,7 +3,7 @@ import os
 import platform
 from framework.utils.log_util import logger
 from framework.global_attribute import CONTEXT
-from config.settings import ALLURE_DIR, ALLURE_REPORT_DIR, ALLURE_RESULTS_DIR, ALLURE_ENV_PROPERTIES
+from framework.settings import ALLURE_DIR, ALLURE_REPORT_DIR, ALLURE_RESULTS_DIR, ALLURE_ENV_PROPERTIES
 
 
 def generate_report():
