@@ -15,6 +15,7 @@ from framework.http_client import ResponseUtil
 from framework.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 from framework.utils.common import snake_to_pascal, SingletonFaker
 from framework.global_attribute import CONFIG, GlobalAttribute, _FRAMEWORK_CONTEXT
+from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed
 
 module = importlib.import_module("test_case.conftest")
 
@@ -114,3 +115,23 @@ class BaseTestCase(object):
             netloc=new_base_parsed.netloc
         )
         return urlunparse(updated_url)
+
+    def get_customized_kytmock(self, request_id):
+        return get_customized_kytmock(self.context.get("env"), request_id)
+
+    def set_customized_kytmock(self, request_id, payment_type: PaymentType, risk_level: RiskLevel, is_delayed: IsDelayed = IsDelayed.NO_DELAY):
+        """
+          参数:
+            env: 环境名称（如
+            "dev", "test"）
+            request_id: 请求ID
+            payment_type: 支付类型枚举
+            risk_level: 风险等级枚举
+            is_delayed: 是否延迟枚举，默认不延迟
+            custom_url: 自定义URL（可选，用于临时测试特殊地址）
+
+            返回:
+            接口响应的JSON字典，失败则返回None
+
+        """
+        return set_customized_kytmock(self.context.get("env"), request_id, payment_type, risk_level, is_delayed)
