@@ -4,7 +4,8 @@ from urllib.parse import urljoin
 
 import allure
 import requests
-import json as built_json
+import simplejson as built_json
+
 from box import Box, BoxList
 from jsonpath import jsonpath as jp
 from requests.models import Response
@@ -22,9 +23,9 @@ class ResponseUtil(object):
     def __init__(self, response: Response):
         self.response = response
         if isinstance(self.response.json(), dict):
-            self.box = Box(convert_numbers_to_decimal(self.response.json()))
+            self.box = Box(built_json.loads(built_json.dumps(convert_numbers_to_decimal(self.response.json()))))
         elif isinstance(self.response.json(), list):
-            self.box = BoxList(convert_numbers_to_decimal(self.response.json()))
+            self.box = BoxList(built_json.loads(built_json.dumps(convert_numbers_to_decimal(self.response.json()))))
         else:
             self.box = self.response.text
 
@@ -111,31 +112,36 @@ class HttpClient(object):
 
             with allure.step(f"请求url: {request_obj.get('url')}"):
                 logger.info(f"请求url: {request_obj.get('url')}")
+
             with allure.step(f"请求method: {request_obj.get('method')}"):
                 logger.info(f"请求method: {request_obj.get('method')}")
-            with allure.step(f"请求headers: {built_json.dumps(request_obj.get('headers'))}"):
-                if CONSOLE_DETAILED_LOG:
 
-                    logger.info(f"请求headers: {built_json.dumps(request_obj.get('headers'))}")
+            with allure.step(f"请求headers: {HttpClient.json(request_obj.get('headers'))}"):
+                if CONSOLE_DETAILED_LOG:
+                    logger.info(f"请求headers: {HttpClient.json(request_obj.get('headers'))}")
+
             if request_obj.get('params'):
-                with allure.step(f"请求参数params: {built_json.dumps(request_obj.get('params'))}"):
-                    logger.info(f"请求参数params: {built_json.dumps(request_obj.get('params'))}")
+                with allure.step(f"请求参数params: {HttpClient.json(request_obj.get('params'))}"):
+                    logger.info(f"请求参数params: {HttpClient.json(request_obj.get('params'))}")
+
             if request_obj.get('data'):
-                with allure.step(f"请求参数data: {built_json.dumps(request_obj.get('data'))}"):
-                    logger.info(f"请求参数data: {built_json.dumps(request_obj.get('data'))}")
+                with allure.step(f"请求参数data: {request_obj.get('data')}"):
+                    logger.info(f"请求参数data: {request_obj.get('data')}")
+
             if request_obj.get('json'):
-                with allure.step(f"请求参数json: {built_json.dumps(request_obj.get('json'))}"):
-                    logger.info(f"请求参数json: {built_json.dumps(request_obj.get('json'))}")
+                with allure.step(f"请求参数json: {HttpClient.json(request_obj.get('json'))}"):
+                    logger.info(f"请求参数json: {HttpClient.json(request_obj.get('json'))}")
 
         with allure.step("响应结果"):
             with allure.step(f"响应status code: {self.response.status_code}"):
                 logger.info(f"响应status code: {self.response.status_code}")
 
-            with allure.step(f"响应headers: {built_json.dumps(dict(self.response.headers))}"):
+            with allure.step(f"响应headers: {HttpClient.json(dict(self.response.headers))}"):
                 if CONSOLE_DETAILED_LOG:
-                    logger.info(f"响应headers: {built_json.dumps(dict(self.response.headers))}")
-            with allure.step(f"响应body: {built_json.dumps(self.response.json())}"):
-                logger.info(f"响应body: {built_json.dumps(self.response.json())}")
+                    logger.info(f"响应headers: {HttpClient.json(dict(self.response.headers))}")
+
+            with allure.step(f"响应body: {HttpClient.json(self.response.json())}"):
+                logger.info(f"响应body: {HttpClient.json(self.response.json())}")
 
         # 断言
         validates = data.get("validate")
@@ -175,3 +181,10 @@ class HttpClient(object):
 
     def update_headers(self, headers):
         self.headers.update(headers)
+
+    @staticmethod
+    def json(dic):
+        try:
+            return built_json.dumps(dic)
+        except:
+            return dic
